==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_Carousel.pm <==
package WebGUI::i18n::German::Asset_Carousel;
use utf8;
our $I18N = {
  'assetName' => {
    'lastUpdated' => '1244064122',
    'message' => 'Carousel'
  },
  'carousel slideWidth description' => {
    'lastUpdated' => '1250973472',
    'message' => 'Breite in Pixel. Die Carouselbreite wird nicht automatische angepasst an den Inhalt. Die Einstellung der Breite unterstützt den Seitenaufbau. Wenn 0, wird die Breite durch die Breite des ersten Elements festgelegt.'
  },
  'carousel slideWidth label' => {
    'lastUpdated' => '1250973525',
    'message' => 'Carousel Frame/Seitenbreite'
  },
  'carousel template description' => {
    'lastUpdated' => '1244064150',
    'message' => 'Selektiere eine Vorlage zu diesem Carousel'
  },
  'carousel template help title' => {
    'lastUpdated' => '1244064195',
    'message' => 'Carousel Vorlage Variabele'
  },
  'carousel template label' => {
    'lastUpdated' => '1244064459',
    'message' => 'Carouselvorlage'
  },
  'id description' => {
    'lastUpdated' => '1244064296',
    'message' => 'Geben Sie eine eindeutige ID für dieses Carouselitem ein.'
  },
  'id label' => {
    'lastUpdated' => '1244064257',
    'message' => 'ID'
  },
  'itemId' => {
    'lastUpdated' => '1244064324',
    'message' => 'Item-Id für dieses Carousel'
  },
  'item_loop' => {
    'lastUpdated' => '1244064403',
    'message' => 'Eine Schleife mit den Items dieses Carousels.'
  },
  'items description' => {
    'lastUpdated' => '1244064429',
    'message' => 'Geben Sie die Items zu diesem Carousel ein.'
  },
  'items label' => {
    'lastUpdated' => '1244064335',
    'message' => 'Items'
  },
  'sequenceNumber' => {
    'lastUpdated' => '1244064369',
    'message' => 'Folgenummer für dieses Carouselitem.'
  },
  'slideWidth' => {
    'lastUpdated' => '1250973281',
    'message' => 'Die Breite für jeden Bereich im Carousel'
  },
  'text' => {
    'lastUpdated' => '1244064238',
    'message' => 'Text zu diesem Carousel Item'
  }
}
;

1;

==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_Carousel.pm <==
package WebGUI::i18n::German::Asset_Carousel;
use utf8;
our $I18N = {
  'assetName' => {
    'lastUpdated' => '1244064122',
    'message' => 'Carousel'
  },
  'carousel slideHeight description' => {
    'lastUpdated' => '1281649002',
    'message' => 'Höhe in Pixel. Das Carousel passt seine Größe nicht selbst automatisch bei unterschiedlichen Höhen an. Das Vorgeben dieser Höhe führt zu einer besseren Darstellung. Beim Standardwert \'0\' wird die Höhe des Carousels auf die Höhe des ersten Carousel-Elements gesetzt.'
  },
  'carousel slideHeight label' => {
    'lastUpdated' => '1279222341',
    'message' => 'Höhe des Carousel-Bereichs '
  },
  'carousel slideWidth description' => {
    'lastUpdated' => '1250973472',
    'message' => 'Breite in Pixel. Die Carouselbreite wird nicht automatische angepasst an den Inhalt. Die Einstellung der Breite unterstützt den Seitenaufbau. Wenn 0, wird die Breite durch die Breite des ersten Elements festgelegt.'
  },
  'carousel slideWidth label' => {
    'lastUpdated' => '1250973525',
    'message' => 'Carousel Frame/Seitenbreite'
  },
  'carousel template description' => {
    'lastUpdated' => '1244064150',
    'message' => 'Selektiere eine Vorlage zu diesem Carousel'
  },
  'carousel template help title' => {
    'lastUpdated' => '1244064195',
    'message' => 'Carousel Vorlage Variabele'
  },
  'carousel template label' => {
    'lastUpdated' => '1244064459',
    'message' => 'Carouselvorlage'
  },
  'id description' => {
    'lastUpdated' => '1244064296',
    'message' => 'Geben Sie eine eindeutige ID für dieses Carouselitem ein.'
  },
  'id label' => {
    'lastUpdated' => '1244064257',
    'message' => 'ID'
  },
  'itemId' => {
    'lastUpdated' => '1244064324',
    'message' => 'Item-Id für dieses Carousel'
  },
  'item_loop' => {
    'lastUpdated' => '1244064403',
    'message' => 'Eine Schleife mit den Items dieses Carousels.'
  },
  'items description' => {
    'lastUpdated' => '1244064429',
    'message' => 'Geben Sie die Items zu diesem Carousel ein.'
  },
  'items label' => {
    'lastUpdated' => '1244064335',
    'message' => 'Items'
  },
  'sequenceNumber' => {
    'lastUpdated' => '1244064369',
    'message' => 'Folgenummer für dieses Carouselitem.'
  },
  'slideHeight' => {
    'lastUpdated' => '1279222307',
    'message' => 'Die Höhe für jeden Bereich im Carousel.'
  },
  'slideWidth' => {
    'lastUpdated' => '1279222314',
    'message' => 'Die Breite für jeden Bereich im Carousel.'
  },
  'text' => {
    'lastUpdated' => '1244064238',
    'message' => 'Text zu diesem Carousel Item'
  }
}
;

1;
